@@ -36,9 +36,17 @@ from ranger.api.options import *
 # Which files should be hidden?  Toggle this by typing `zh' or
 # changing the setting `show_hidden'
 hidden_filter = regexp(
-	r'^\.|\.(?:pyc|pyo|bak|swp)$|~$|lost\+found')
+	r'^\.|\.(?:pyc|pyo|bak|swp)$|^lost\+found$')
 show_hidden = False
 
+# Which script is used to generate file previews?
+# Ranger ships with scope.sh, a script that calls external programs (see
+# README for dependencies) to preview images, archives, etc.
+preview_script = '~/.config/ranger/scope.sh'
+
+# Use that external preview script or display internal plain text previews?
+use_preview_script = True
+
 # Show dotfiles in the bookmark preview box?
 show_hidden_bookmarks = True
 
@@ -93,6 +101,10 @@ scroll_offset = 8
 # Flush the input after each key hit?  (Noticable when ranger lags)
 flushinput = True
 
+# Padding on the right when there's no preview?
+# This allows you to click into the space to run the file.
+padding_right = True
+
 # Save bookmarks (used with mX and `X) instantly?
 # This helps to synchronize bookmarks between multiple ranger
 # instances but leads to *slight* performance loss.
